from typing import overload
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation


class BaseWrappedException_HostLocation(BaseWrappedException_SourceLocation):
	location: str

	@overload
	def __init__(self, location: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_projectile_PersistentProjectileEntity = TypeVar("net_minecraft_entity_projectile_PersistentProjectileEntity")
PersistentProjectileEntity = net_minecraft_entity_projectile_PersistentProjectileEntity


class ArrowEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PersistentProjectileEntity) -> None:
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the particle's color of the arrow, or '-1' if the arrow has no particles. 
		"""
		pass

	@overload
	def isCritical(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the arrow will deal critical damage, 'false' otherwise. 
		"""
		pass

	@overload
	def getPiercingLevel(self) -> int:
		"""The piercing level will only be set if the arrow was fired from a crossbow with the piercing
enchantment.\n
		Since: 1.8.4 

		Returns:
			the piercing level of the arrow. 
		"""
		pass

	@overload
	def isShotFromCrossbow(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the arrow is shot from a crossbow, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_passive_IronGolemEntity = TypeVar("net_minecraft_entity_passive_IronGolemEntity")
IronGolemEntity = net_minecraft_entity_passive_IronGolemEntity


class IronGolemEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: IronGolemEntity) -> None:
		pass

	@overload
	def isPlayerCreated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this iron golem was created by a player, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
from .Sorting_ServiceSortMethod import Sorting_ServiceSortMethod

com_google_gson_JsonObject = TypeVar("com_google_gson_JsonObject")
JsonObject = com_google_gson_JsonObject

java_util_Comparator_java_lang_String_ = TypeVar("java_util_Comparator_java_lang_String_")
Comparator = java_util_Comparator_java_lang_String_


class ClientConfigV2:
	sortMethod: Sorting_MacroSortMethod
	sortServicesMethod: Sorting_ServiceSortMethod
	showSlotIndexes: bool
	disableKeyWhenScreenOpen: bool
	editorTheme: Mapping[str, List[float]]
	editorLinterOverrides: Mapping[str, str]
	editorHistorySize: int
	editorSuggestions: bool
	editorFont: str
	externalEditor: bool
	externalEditorCommand: str
	showRunningServices: bool
	serviceAutoReload: bool

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def languages(self) -> List[str]:
		pass

	@overload
	def getFonts(self) -> List[str]:
		pass

	@overload
	def getThemeData(self) -> Mapping[str, List[float]]:
		pass

	@overload
	def setServiceAutoReload(self, value: bool) -> None:
		pass

	@overload
	def getSortComparator(self) -> Comparator:
		pass

	@overload
	def getServiceSortComparator(self) -> Comparator:
		pass

	@overload
	def fromV1(self, v1: JsonObject) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from typing import Set

T = TypeVar("T")

class StringHashTrie:
	"""Is this even faster than just iterating through a LinkedHashSet / HashSet at this point?
also should the node-length just always be 1?
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def size(self) -> int:
		pass

	@overload
	def isEmpty(self) -> bool:
		pass

	@overload
	def contains(self, o: object) -> bool:
		pass

	@overload
	def iterator(self) -> iter:
		pass

	@overload
	def toArray(self) -> List[str]:
		pass

	@overload
	def toArray(self, a: List[T]) -> List[T]:
		pass

	@overload
	def add(self, s: str) -> bool:
		pass

	@overload
	def remove(self, o: object) -> bool:
		"""this can make the StringHashTrie sparse, this can cause extra steps in lookup that are no longer needed,
at some point it would be best to rebase the StringHashTrie with 'new StringHashTrie().addAll(current.getAll())'

		Args:
			o: 
		"""
		pass

	@overload
	def containsAll(self, c: List[Any]) -> bool:
		pass

	@overload
	def containsAll(self, o: List[str]) -> bool:
		pass

	@overload
	def addAll(self, c: List[Any]) -> bool:
		pass

	@overload
	def addAll(self, o: List[str]) -> bool:
		pass

	@overload
	def removeAll(self, c: List[Any]) -> bool:
		pass

	@overload
	def removeAll(self, o: List[str]) -> bool:
		pass

	@overload
	def retainAll(self, c: List[Any]) -> bool:
		pass

	@overload
	def retainAll(self, o: List[str]) -> bool:
		pass

	@overload
	def clear(self) -> None:
		pass

	@overload
	def getAllWithPrefix(self, prefix: str) -> Set[str]:
		"""

		Args:
			prefix: prefix to search with 

		Returns:
			all elements that start with the given prefix 
		"""
		pass

	@overload
	def getAllWithPrefixCaseInsensitive(self, prefix: str) -> Set[str]:
		"""

		Args:
			prefix: prefix to search with 

		Returns:
			all elements that start with the given prefix (case insensitive) 
		"""
		pass

	@overload
	def getAll(self) -> Set[str]:
		"""all contained elements as a Set
		"""
		pass

	@overload
	def toString(self) -> str:
		"""

		Returns:
			json representation, mainly for debugging. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MethodWrapper import MethodWrapper

java_util_function_Function_xyz_wagyourtail_jsmacros_core_event_BaseEvent,xyz_wagyourtail_jsmacros_core_language_EventContainer_xyz_wagyourtail_jsmacros_core_language_BaseScriptContext____ = TypeVar("java_util_function_Function_xyz_wagyourtail_jsmacros_core_event_BaseEvent,xyz_wagyourtail_jsmacros_core_language_EventContainer_xyz_wagyourtail_jsmacros_core_language_BaseScriptContext____")
Function = java_util_function_Function_xyz_wagyourtail_jsmacros_core_event_BaseEvent,xyz_wagyourtail_jsmacros_core_language_EventContainer_xyz_wagyourtail_jsmacros_core_language_BaseScriptContext____

T = TypeVar("T")
U = TypeVar("U")
V = TypeVar("V")
V = V


class WrappedScript(Generic[T, U, V], MethodWrapper):
	f: Function
	_async: bool

	@overload
	def __init__(self, f: Function, _async: bool) -> None:
		pass

	@overload
	def accept(self, t: T) -> None:
		pass

	@overload
	def accept(self, t: T, u: U) -> None:
		pass

	@overload
	def apply(self, t: T) -> V:
		pass

	@overload
	def apply(self, t: T, u: U) -> V:
		pass

	@overload
	def test(self, t: T) -> bool:
		pass

	@overload
	def test(self, t: T, u: U) -> bool:
		pass

	@overload
	def run(self) -> None:
		pass

	@overload
	def compare(self, o1: T, o2: T) -> int:
		pass

	@overload
	def get(self) -> V:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .BaseLibrary import BaseLibrary

T = TypeVar("T")
U = TypeVar("U")

class PerExecLanguageLibrary(Generic[U, T], BaseLibrary):

	@overload
	def __init__(self, context: T, language: Class) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .ServiceScreen import ServiceScreen
from .ServiceTrigger import ServiceTrigger

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

java_io_File = TypeVar("java_io_File")
File = java_io_File

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class ServiceContainer(MultiElementContainer):
	service: str

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: ServiceScreen, service: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def getEnabled(self) -> bool:
		pass

	@overload
	def getRunning(self) -> bool:
		pass

	@overload
	def getTrigger(self) -> ServiceTrigger:
		pass

	@overload
	def setFile(self, file: File) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic

T = TypeVar("T")

class WrappedClassInstance(Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, instance: T) -> None:
		pass

	@overload
	def __init__(self, instanceNullable: T, tClass: Class) -> None:
		pass

	@overload
	def getFieldValue(self, fieldName: str) -> object:
		pass

	@overload
	def getFieldValueAsClass(self, asClass: str, fieldName: str) -> object:
		pass

	@overload
	def setFieldValue(self, fieldName: str, fieldValue: object) -> None:
		pass

	@overload
	def setFieldValueAsClass(self, asClass: str, fieldName: str, fieldValue: object) -> None:
		pass

	@overload
	def invokeMethod(self, methodNameOrSig: str, params: List[object]) -> object:
		pass

	@overload
	def invokeMethodAsClass(self, asClass: str, methodNameOrSig: str, params: List[object]) -> object:
		pass

	@overload
	def getRawInstance(self) -> T:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getRawClass(self) -> Class:
		"""
		Since: 1.6.5 
		"""
		pass

	pass





from typing import overload
from .OptionsHelper import OptionsHelper


class OptionsHelper_SkinOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def isCapeActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's cape should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isJacketActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's jacket should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isLeftSleeveActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's left sleeve should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isRightSleeveActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's right sleeve should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isLeftPantsActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's left pants should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isRightPantsActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's right pants should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isHatActivated(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's hat should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def isRightHanded(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's main hand is the right one, 'false' otherwise. 
		"""
		pass

	@overload
	def isLeftHanded(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the player's main hand is the left one, 'false' otherwise. 
		"""
		pass

	@overload
	def toggleCape(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the cape should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleJacket(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the jacket should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleLeftSleeve(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the left sleeve should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleRightSleeve(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the right sleeve should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleLeftPants(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the left pants should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleRightPants(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the right pants should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleHat(self, val: bool) -> "OptionsHelper_SkinOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether the hat should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toggleMainHand(self, hand: str) -> "OptionsHelper_SkinOptionsHelper":
		"""The hand must be either '"left"' or '"right"' .\n
		Since: 1.8.4 

		Args:
			hand: the hand to set as main hand 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from .AbstractWidgetBuilder import AbstractWidgetBuilder
from .IScreen import IScreen
from .MethodWrapper import MethodWrapper
from .CheckBoxWidgetHelper import CheckBoxWidgetHelper


class CheckBoxWidgetHelper_CheckBoxBuilder(AbstractWidgetBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, screen: IScreen) -> None:
		pass

	@overload
	def isChecked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the checkbox is initially checked, 'false' otherwise. 
		"""
		pass

	@overload
	def checked(self, checked: bool) -> "CheckBoxWidgetHelper_CheckBoxBuilder":
		"""
		Since: 1.8.4 

		Args:
			checked: whether the checkbox is initially checked or not 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAction(self) -> MethodWrapper:
		"""
		Since: 1.8.4 

		Returns:
			the action to run when the button is pressed. 
		"""
		pass

	@overload
	def action(self, action: MethodWrapper) -> "CheckBoxWidgetHelper_CheckBoxBuilder":
		"""
		Since: 1.8.4 

		Args:
			action: the action to run when the button is pressed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def createWidget(self) -> CheckBoxWidgetHelper:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

java_util_function_Function_T,java_lang_Boolean_ = TypeVar("java_util_function_Function_T,java_lang_Boolean_")
Function = java_util_function_Function_T,java_lang_Boolean_

T = TypeVar("T")

class IFilter(Function, Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def apply(self, t: T) -> bool:
		pass

	pass





from typing import overload
from .EventFilterer_Compound import EventFilterer_Compound
from .EventFilterer import EventFilterer
from .BaseEvent import BaseEvent


class FiltererInverted(EventFilterer_Compound):
	"""
	Since: 1.9.1 
	"""
	base: EventFilterer

	@overload
	def invert(self, base: EventFilterer) -> EventFilterer:
		pass

	@overload
	def canFilter(self, event: str) -> bool:
		pass

	@overload
	def test(self, event: BaseEvent) -> bool:
		pass

	@overload
	def checkCyclicRef(self, base: EventFilterer_Compound) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .PlayerEntityHelper import PlayerEntityHelper
from .Pos3D import Pos3D
from .BlockPosHelper import BlockPosHelper
from .EntityHelper import EntityHelper
from .AdvancementManagerHelper import AdvancementManagerHelper
from .BlockStateHelper import BlockStateHelper
from .ItemStackHelper import ItemStackHelper

T = TypeVar("T")

class ClientPlayerEntityHelper(Generic[T], PlayerEntityHelper):
	"""
	Since: 1.0.3 
	"""

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def setVelocity(self, velocity: Pos3D) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def setVelocity(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def addVelocity(self, velocity: Pos3D) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def addVelocity(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def setPos(self, pos: Pos3D) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def setPos(self, pos: Pos3D, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def setPos(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def setPos(self, x: float, y: float, z: float, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addPos(self, pos: Pos3D) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def addPos(self, pos: Pos3D, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def addPos(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 
		"""
		pass

	@overload
	def addPos(self, x: float, y: float, z: float, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def lookAt(self, direction: str) -> "ClientPlayerEntityHelper":
		"""Sets the player rotation along the given axis and keeps the other axis the same.\n
		Since: 1.8.4 

		Args:
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def lookAt(self, yaw: float, pitch: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.0.3 

		Args:
			pitch: (was yaw prior to 1.2.6) 
			yaw: (was pitch prior to 1.2.6) 
		"""
		pass

	@overload
	def lookAt(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""look at the specified coordinates.\n
		Since: 1.2.8 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def tryLookAt(self, x: int, y: int, z: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the block to look at 
			y: the y coordinate of the block to look at 
			z: the z coordinate of the block to look at 

		Returns:
			'true' if the player is targeting the specified block, 'false' otherwise. 
		"""
		pass

	@overload
	def tryLookAt(self, pos: BlockPosHelper) -> bool:
		"""Will try many rotations to find one that will make the player target the specified block. If
successful, the player will be turned towards the block and 'true' will be returned. If 'false' is returned, the player will keep its current rotation.\n
		Since: 1.8.4 

		Args:
			pos: the position of the block to look at 

		Returns:
			'true' if the player is targeting the specified block, 'false' otherwise. 
		"""
		pass

	@overload
	def turnLeft(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def turnRight(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def turnBack(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 

		Args:
			entity: 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: str) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to attack 
			y: the y coordinate to attack 
			z: the z coordinate to attack 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: str, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to attack 
			await: whether to wait for the attack to finish 
			y: the y coordinate to attack 
			z: the z coordinate to attack 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			x: 
			await: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: str, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to interact 
			y: the y coordinate to interact 
			z: the z coordinate to interact 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: str, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to interact 
			await: whether to wait for the interaction to complete 
			y: the y coordinate to interact 
			z: the z coordinate to interact 
			direction: possible values are "up", "down", "north", "south", "east", "west" 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			x: 
			await: whether to wait for the interaction to complete 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
			offHand: 
		"""
		pass

	@overload
	def interact(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def interact(self, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def attack(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def attack(self, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def setLongAttack(self, stop: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.3 

		Args:
			stop: 
		"""
		pass

	@overload
	def setLongInteract(self, stop: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.3 

		Args:
			stop: 
		"""
		pass

	@overload
	def getItemCooldownsRemainingTicks(self) -> Mapping[str, int]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getItemCooldownRemainingTicks(self, item: str) -> int:
		"""
		Since: 1.6.5 

		Args:
			item: 
		"""
		pass

	@overload
	def getTicksSinceCooldownsStart(self) -> Mapping[str, int]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getTicksSinceCooldownStart(self, item: str) -> int:
		"""
		Since: 1.6.5 

		Args:
			item: 
		"""
		pass

	@overload
	def getFoodLevel(self) -> int:
		"""
		Since: 1.1.2 
		"""
		pass

	@overload
	def getSaturation(self) -> float:
		"""This will return the invisible hunger decade that you may have seen in mods as a yellow overlay.\n
		Since: 1.8.4 

		Returns:
			the saturation level. 
		"""
		pass

	@overload
	def dropHeldItem(self, dropStack: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAdvancementManager(self) -> AdvancementManagerHelper:
		"""
		Since: 1.8.4 

		Returns:
			an advancement manager to work with advancements. 
		"""
		pass

	@overload
	def calculateMiningSpeed(self, block: BlockStateHelper) -> int:
		"""The returned time is an approximation and will likely be off by a few ticks, although it
should always be less than the actual time.

		Args:
			block: the block to mine 

		Returns:
			the time in ticks that it will approximately take the player with the currently held
item to mine said block. 
		"""
		pass

	@overload
	def calculateMiningSpeed(self, usedItem: ItemStackHelper, blockState: BlockStateHelper) -> int:
		"""Calculate mining speed for a given block mined with a specified item in ticks. Use air to
calculate the mining speed for the hand. The returned time is an approximation and will
likely be off by a few ticks, although it should always be less than the actual time.\n
		Since: 1.8.4 

		Args:
			blockState: the block to mine 
			usedItem: the item to mine with 

		Returns:
			the time in ticks that it will approximately take the player with the specified item
to mine said block. 
		"""
		pass

	pass





from typing import overload
from .IMerchantEntity import IMerchantEntity


class MixinMerchantEntity(IMerchantEntity):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_refreshOffers(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping

net_minecraft_client_gui_hud_ClientBossBar = TypeVar("net_minecraft_client_gui_hud_ClientBossBar")
ClientBossBar = net_minecraft_client_gui_hud_ClientBossBar

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID


class IBossBarHud:

	@overload
	def jsmacros_GetBossBars(self) -> Mapping[UUID, ClientBossBar]:
		pass

	pass





from typing import overload
from .ClassBuilder import ClassBuilder
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder
from .ClassBuilder_FieldBuilder_FieldInitializerBuilder import ClassBuilder_FieldBuilder_FieldInitializerBuilder


class ClassBuilder_FieldBuilder:
	fieldInitializer: CtField_Initializer

	@overload
	def __init__(self, fieldType: CtClass, name: str) -> None:
		pass

	@overload
	def compile(self, code: str) -> "ClassBuilder":
		pass

	@overload
	def rename(self, name: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def makePrivate(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def makePublic(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def makeProtected(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def makePackagePrivate(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def toggleStatic(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def toggleFinal(self) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def getMods(self) -> int:
		pass

	@overload
	def getModString(self) -> str:
		pass

	@overload
	def addAnnotation(self, type: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def initializer(self) -> "ClassBuilder_FieldBuilder_FieldInitializerBuilder":
		pass

	@overload
	def end(self) -> "ClassBuilder":
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack

net_minecraft_screen_PropertyDelegate = TypeVar("net_minecraft_screen_PropertyDelegate")
PropertyDelegate = net_minecraft_screen_PropertyDelegate


class MixinAbstractFurnaceScreenHandler:
	"""
	Since: 1.8.4 
	"""

	@overload
	def invokeIsSmeltable(self, itemStack: ItemStack) -> bool:
		pass

	@overload
	def invokeIsFuel(self, itemStack: ItemStack) -> bool:
		pass

	@overload
	def getPropertyDelegate(self) -> PropertyDelegate:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder import ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder

T = TypeVar("T")

class ClassBuilder_AnnotationBuilder(Generic[T]):

	@overload
	def putString(self, key: str, value: str) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putBoolean(self, key: str, value: bool) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putByte(self, key: str, value: float) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putChar(self, key: str, value: str) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putShort(self, key: str, value: float) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putInt(self, key: str, value: int) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putLong(self, key: str, value: float) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putFloat(self, key: str, value: float) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putDouble(self, key: str, value: float) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putClass(self, key: str, value: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putEnum(self, key: str, value: ) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putAnnotation(self, key: str, annotationClass: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def putArray(self, key: str) -> "ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder":
		pass

	@overload
	def finish(self) -> T:
		pass

	pass





from typing import overload
from typing import List
from .IDraw2D import IDraw2D
from .ClickableWidgetHelper import ClickableWidgetHelper
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .MethodWrapper import MethodWrapper
from .CheckBoxWidgetHelper import CheckBoxWidgetHelper
from .SliderWidgetHelper import SliderWidgetHelper
from .LockButtonWidgetHelper import LockButtonWidgetHelper
from .CyclingButtonWidgetHelper import CyclingButtonWidgetHelper
from .ButtonWidgetHelper_ButtonBuilder import ButtonWidgetHelper_ButtonBuilder
from .CheckBoxWidgetHelper_CheckBoxBuilder import CheckBoxWidgetHelper_CheckBoxBuilder
from .CyclingButtonWidgetHelper_CyclicButtonBuilder import CyclingButtonWidgetHelper_CyclicButtonBuilder
from .LockButtonWidgetHelper_LockButtonBuilder import LockButtonWidgetHelper_LockButtonBuilder
from .SliderWidgetHelper_SliderBuilder import SliderWidgetHelper_SliderBuilder
from .TextFieldWidgetHelper_TextFieldBuilder import TextFieldWidgetHelper_TextFieldBuilder
from .ButtonWidgetHelper_TexturedButtonBuilder import ButtonWidgetHelper_TexturedButtonBuilder


class IScreen(IDraw2D):
	"""
	Since: 1.2.7 
	"""

	@overload
	def getScreenClassName(self) -> str:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getTitleText(self) -> str:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getButtonWidgets(self) -> List[ClickableWidgetHelper]:
		"""in '1.3.1' updated to work with all button widgets not just ones added by scripts.\n
		Since: 1.0.5 
		"""
		pass

	@overload
	def getTextFields(self) -> List[TextFieldWidgetHelper]:
		"""in '1.3.1' updated to work with all text fields not just ones added by scripts.\n
		Since: 1.0.5 
		"""
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, text: str, callback: MethodWrapper) -> ClickableWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			x: 
			width: 
			y: 
			callback: calls your method as a Consumer ClickableWidgetHelper 
			text: 
			height: 
		"""
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, callback: MethodWrapper) -> ClickableWidgetHelper:
		"""
		Since: 1.4.0 

		Args:
			x: 
			width: 
			y: 
			callback: calls your method as a Consumer ClickableWidgetHelper 
			text: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, text: str, checked: bool, showMessage: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			showMessage: whether to show the message or not 
			x: the x position of the checkbox 
			width: the width of the checkbox 
			y: the y position of the checkbox 
			checked: whether the checkbox is checked or not 
			callback: calls your method as a Consumer CheckBoxWidgetHelper 
			text: the text to display next to the checkbox 
			height: the height of the checkbox 

		Returns:
			a CheckBoxWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, text: str, checked: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the checkbox 
			width: the width of the checkbox 
			y: the y position of the checkbox 
			checked: whether the checkbox is checked or not 
			callback: calls your method as a Consumer CheckBoxWidgetHelper 
			text: the text to display next to the checkbox 
			height: the height of the checkbox 

		Returns:
			a CheckBoxWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, checked: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the checkbox 
			width: the width of the checkbox 
			y: the y position of the checkbox 
			checked: whether the checkbox is checked or not 
			callback: calls your method as a Consumer CheckBoxWidgetHelper 
			text: the text to display next to the checkbox 
			height: the height of the checkbox 
			zIndex: the z-index of the checkbox 

		Returns:
			a CheckBoxWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCheckbox(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, checked: bool, showMessage: bool, callback: MethodWrapper) -> CheckBoxWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			showMessage: whether to show the message or not 
			x: the x position of the checkbox 
			width: the width of the checkbox 
			y: the y position of the checkbox 
			checked: whether the checkbox is checked or not 
			callback: calls your method as a Consumer CheckBoxWidgetHelper 
			text: the text to display next to the checkbox 
			height: the height of the checkbox 
			zIndex: the z-index of the checkbox 

		Returns:
			a CheckBoxWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, text: str, value: float, steps: int, callback: MethodWrapper) -> SliderWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the slider 
			width: the width of the slider 
			y: the y position of the slider 
			callback: calls your method as a Consumer SliderWidgetHelper 
			text: the text to be displayed inside the slider 
			value: the initial value of the slider 
			steps: the number of steps the slider should have 
			height: the height of the slider 

		Returns:
			a SliderWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, value: float, steps: int, callback: MethodWrapper) -> SliderWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the slider 
			width: the width of the slider 
			y: the y position of the slider 
			callback: calls your method as a Consumer SliderWidgetHelper 
			text: the text to be displayed inside the slider 
			value: the initial value of the slider 
			steps: the number of steps the slider should have 
			height: the height of the slider 
			zIndex: the z-index of the slider 

		Returns:
			a SliderWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, text: str, value: float, callback: MethodWrapper) -> SliderWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the slider 
			width: the width of the slider 
			y: the y position of the slider 
			callback: calls your method as a Consumer SliderWidgetHelper 
			text: the text to be displayed inside the slider 
			value: the initial value of the slider 
			height: the height of the slider 

		Returns:
			a SliderWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addSlider(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, value: float, callback: MethodWrapper) -> SliderWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the slider 
			width: the width of the slider 
			y: the y position of the slider 
			callback: calls your method as a Consumer SliderWidgetHelper 
			text: the text to be displayed inside the slider 
			value: the initial value of the slider 
			height: the height of the slider 
			zIndex: the z-index of the slider 

		Returns:
			a SliderWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addLockButton(self, x: int, y: int, callback: MethodWrapper) -> LockButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the lock button 
			y: the y position of the lock button 
			callback: calls your method as a Consumer LockButtonWidgetHelper 

		Returns:
			LockButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addLockButton(self, x: int, y: int, zIndex: int, callback: MethodWrapper) -> LockButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the lock button 
			y: the y position of the lock button 
			callback: calls your method as a Consumer LockButtonWidgetHelper 
			zIndex: the z-index of the lock button 

		Returns:
			LockButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, values: List[str], initial: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			initial: the initial value of the cycling button 
			values: the values to cycle through 
			x: the x position of the cycling button 
			width: the width of the cycling button 
			y: the y position of the cycling button 
			callback: calls your method as a Consumer CyclingButtonWidgetHelper 
			height: the height of the cycling button 

		Returns:
			CyclingButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], initial: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			initial: the initial value of the cycling button 
			values: the values to cycle through 
			x: the x position of the cycling button 
			width: the width of the cycling button 
			y: the y position of the cycling button 
			callback: calls your method as a Consumer CyclingButtonWidgetHelper 
			height: the height of the cycling button 
			zIndex: the z-index of the cycling button 

		Returns:
			CyclingButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], alternatives: List[str], initial: str, prefix: str, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			initial: the initial value of the cycling button 
			prefix: the prefix of the values 
			values: the values to cycle through 
			x: the x position of the cycling button 
			width: the width of the cycling button 
			y: the y position of the cycling button 
			callback: calls your method as a Consumer CyclingButtonWidgetHelper 
			alternatives: the alternative values to cycle through 
			height: the height of the cycling button 
			zIndex: the z-index of the cycling button 

		Returns:
			CyclingButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def addCyclingButton(self, x: int, y: int, width: int, height: int, zIndex: int, values: List[str], alternatives: List[str], initial: str, prefix: str, alternateToggle: MethodWrapper, callback: MethodWrapper) -> CyclingButtonWidgetHelper:
		"""
		Since: 1.8.4 

		Args:
			alternateToggle: the method to determine if the cycling button should use the
                       alternative values 
			initial: the initial value of the cycling button 
			prefix: the prefix of the values 
			values: the values to cycle through 
			x: the x position of the cycling button 
			width: the width of the cycling button 
			y: the y position of the cycling button 
			callback: calls your method as a Consumer CyclingButtonWidgetHelper 
			alternatives: the alternative values to cycle through 
			height: the height of the cycling button 
			zIndex: the z-index of the cycling button 

		Returns:
			CyclingButtonWidgetHelper for the given input. 
		"""
		pass

	@overload
	def removeButton(self, btn: ClickableWidgetHelper) -> "IScreen":
		"""
		Since: 1.0.5 

		Args:
			btn: 
		"""
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			onChange: calls your method as a Consumer String 
			x: 
			width: 
			y: 
			message: 
			height: 
		"""
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, zIndex: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			onChange: calls your method as a Consumer String 
			x: 
			width: 
			y: 
			message: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def removeTextInput(self, inp: TextFieldWidgetHelper) -> "IScreen":
		"""
		Since: 1.0.5 

		Args:
			inp: 
		"""
		pass

	@overload
	def setOnMouseDown(self, onMouseDown: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseDown: calls your method as a BiConsumer Pos2D , Integer 
		"""
		pass

	@overload
	def setOnMouseDrag(self, onMouseDrag: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseDrag: calls your method as a BiConsumer Vec2D , Integer 
		"""
		pass

	@overload
	def setOnMouseUp(self, onMouseUp: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseUp: calls your method as a BiConsumer Pos2D , Integer 
		"""
		pass

	@overload
	def setOnScroll(self, onScroll: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onScroll: calls your method as a BiConsumer Pos2D , Double 
		"""
		pass

	@overload
	def setOnKeyPressed(self, onKeyPressed: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onKeyPressed: calls your method as a BiConsumer Integer , Integer 
		"""
		pass

	@overload
	def setOnCharTyped(self, onCharTyped: MethodWrapper) -> "IScreen":
		"""
		Since: 1.8.4 

		Args:
			onCharTyped: calls your method as a BiConsumer Character , Integer 
		"""
		pass

	@overload
	def setOnClose(self, onClose: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onClose: calls your method as a Consumer IScreen 
		"""
		pass

	@overload
	def close(self) -> None:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def reloadScreen(self) -> "IScreen":
		"""calls the screen's init function re-loading it.\n
		Since: 1.2.7 
		"""
		pass

	@overload
	def buttonBuilder(self) -> ButtonWidgetHelper_ButtonBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for buttons. 
		"""
		pass

	@overload
	def checkBoxBuilder(self) -> CheckBoxWidgetHelper_CheckBoxBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for checkboxes. 
		"""
		pass

	@overload
	def checkBoxBuilder(self, checked: bool) -> CheckBoxWidgetHelper_CheckBoxBuilder:
		"""
		Since: 1.8.4 

		Args:
			checked: whether the checkbox should be checked by default 

		Returns:
			a new builder for checkboxes. 
		"""
		pass

	@overload
	def cyclicButtonBuilder(self, valueToText: MethodWrapper) -> CyclingButtonWidgetHelper_CyclicButtonBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for cycling buttons. 
		"""
		pass

	@overload
	def lockButtonBuilder(self) -> LockButtonWidgetHelper_LockButtonBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for lock buttons. 
		"""
		pass

	@overload
	def lockButtonBuilder(self, locked: bool) -> LockButtonWidgetHelper_LockButtonBuilder:
		"""
		Since: 1.8.4 

		Args:
			locked: whether the lock button should be locked by default 

		Returns:
			a new builder for lock buttons. 
		"""
		pass

	@overload
	def sliderBuilder(self) -> SliderWidgetHelper_SliderBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for sliders. 
		"""
		pass

	@overload
	def textFieldBuilder(self) -> TextFieldWidgetHelper_TextFieldBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for text fields. 
		"""
		pass

	@overload
	def texturedButtonBuilder(self) -> ButtonWidgetHelper_TexturedButtonBuilder:
		"""
		Since: 1.8.4 

		Returns:
			a new builder for textured buttons. 
		"""
		pass

	@overload
	def isShiftDown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the shift key is pressed, 'false' otherwise. 
		"""
		pass

	@overload
	def isCtrlDown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the ctrl key is pressed, 'false' otherwise. 
		"""
		pass

	@overload
	def isAltDown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the alt key is pressed, 'false' otherwise. 
		"""
		pass

	@overload
	def getOnClose(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_screen_slot_Slot = TypeVar("net_minecraft_screen_slot_Slot")
Slot = net_minecraft_screen_slot_Slot


class IInventory:

	@overload
	def jsmacros$getX(self) -> int:
		pass

	@overload
	def jsmacros$getY(self) -> int:
		pass

	@overload
	def jsmacros_getSlotUnder(self, x: float, y: float) -> Slot:
		pass

	pass





from typing import overload
from .BlockPosHelper import BlockPosHelper


class InteractionProxy_Break_BreakBlockResult:
	UNAVAILABLE: "InteractionProxy_Break_BreakBlockResult"
	reason: str
	pos: BlockPosHelper

	@overload
	def __init__(self, reason: str, pos: BlockPosHelper) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List


class Extension_ExtMatch:
	NOT_MATCH: "Extension_ExtMatch"
	MATCH: "Extension_ExtMatch"
	MATCH_WITH_NAME: "Extension_ExtMatch"

	@overload
	def values(self) -> List["Extension_ExtMatch"]:
		pass

	@overload
	def valueOf(self, name: str) -> "Extension_ExtMatch":
		pass

	@overload
	def isMatch(self) -> bool:
		pass

	pass


